# ghsearch

Github search from the cli

## Features

<!---
- feature 1
- feature 2
-->

## Installation

```
pip install gh-search
```

## Usage

<!---
Rather than starting to delve into the API docs, this section shows how the module looks like in action.
Just one or few most common use cases should be shown.
-->

## Developing

When making changes to the module it is always a good idea to run everything within a Python virtual environment to ensure isolation of dependencies.

```bash
# Python3
pyvenv venv
source venv/bin/activate
make install-dev
```

Unit tests are written using pytest and can be run from the root of the project with

```bash
make unit
```

```bash
make lint
```
